#!/bin/bash
#
# source: http://hal.freedesktop.org/releases/hal-0.5.14.tar.bz2
#
# maintainer: gmg (monpontet.gerard@neuf.fr)
#

#------------------Set Some Variables

soft="hal"
softversion="0.5.14"
arch="i486"
cpu="i686"
packageversion="69.1"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tgz
rm -rf $dest

#------------------Start Configure

cd $src

# Restore Xorg's Zap'ing behavior by default and make it
# clearer to the user how to edit and/or get back old behavior
zcat $buildir/patches/10-keymap.fdi-restore_zap.diff.gz | patch -p1 --verbose || exit 1
zcat $buildir/patches/fix-libusb-detection.patch.gz | patch -p1 --verbose || exit 1 
# Make sure ownerships and permissions are sane:
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --mandir=/usr/man \
  --disable-static \
  --docdir=/usr/doc/$soft-$softversion \
  --enable-gtk-doc=no \
  --with-udev-prefix=/lib \
  --enable-policy-kit=no \
  --enable-acpi-ibm \
  --enable-acpi-toshiba \
  --enable-umount-helper \
  --enable-sonypic \
  --with-pid-file=/var/run/hald.pid

make || exit 1
make install DESTDIR=$dest || exit 1

find $dest | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Compress man pages
( cd $dest/usr/man
  find . -type f -exec gzip -9 {} \;
  for i in $(find . -type l) ; do ln -s $(readlink $i).gz $i.gz ; rm $i ; done
)

rm -rf $dest/etc/udev

# Install init script for hal
mkdir -p $dest/etc/rc.d
zcat $buildir/rc.hald.gz > $dest/etc/rc.d/rc.hald.new
# Make HAL run by default:
chmod 0755 $dest/etc/rc.d/rc.hald.new

mkdir -p $dest/usr/doc/$soft-$softversion
mv $dest/etc/dbus-1/system.d/hal.conf $dest/etc/dbus-1/system.d/hal.conf.new

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
  AUTHORS COPYING* HACKING INSTALL NEWS README* \
  $dest/usr/doc/$soft-$softversion
( cd $dest/usr/doc/$soft-$softversion
  ln -s ../../share/gtk-doc/html/libhal libhal
  ln -s ../../share/gtk-doc/html/libhal-storage libhal-storage
)

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
hal: hal - is Hardware Abstraction Layer
hal:
hal: HAL is a piece of software that provides a view of the various
hal: hardware attached to a system.  HAL keeps detailed metadata for each
hal: piece of hardware and provides hooks so that system and desktop
hal: software can react to changes in the hardware configuration (such as
hal: the insertion of a DVD, or a USB flash memory stick).  Users in the
hal: "plugdev" or "cdrom" group will be able to use such devices on the
hal: desktop without the need to mount/umount them manually.
hal:
hal: For more info, see:  http://www.freedesktop.org/Software/hal
EOF

# zcat $buildir/doinst.sh.gz > $dest/install/doinst.sh



cat << "EOF" > $dest/install/doinst.sh
#!/bin/sh

config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
    # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

# Keep same perms on rc.hald.new:
if [ -e etc/rc.d/rc.hald ]; then
  cp -a etc/rc.d/rc.hald etc/rc.d/rc.hald.new.incoming
  cat etc/rc.d/rc.hald.new > etc/rc.d/rc.hald.new.incoming
  mv etc/rc.d/rc.hald.new.incoming etc/rc.d/rc.hald.new
fi

config etc/rc.d/rc.hald.new
config etc/dbus-1/system.d/hal.conf.new

# If the haldaemon group doesn't exist, add them
if ! grep "^haldaemon:" etc/group >/dev/null 2>&1; then
  echo "haldaemon:x:82:" >>etc/group
fi
if ! grep "^haldaemon:" etc/gshadow >/dev/null 2>&1; then
  echo "haldaemon:!::" >>etc/gshadow
fi

# If the polkituser user doesn't exist, add it
if ! grep "^haldaemon:" etc/passwd >/dev/null 2>&1; then
  echo "haldaemon:x:82:82:User for HAL:/var/run/hald:/bin/false" >>etc/passwd
fi
if ! grep "^haldaemon:" etc/shadow >/dev/null 2>&1; then
  echo "haldaemon:!!:9797:0:::::" >>etc/shadow
fi

EOF


# Suspend / Hibernate fixes
cat << "EOF" > $dest/usr/libexec/scripts/hal-system-power-hibernate
#!/bin/sh
/usr/sbin/hibernate

EOF

cat << "EOF" > $dest/usr/libexec/scripts/hal-system-power-suspend
#!/bin/sh
/usr/sbin/standby

EOF

cat << "EOF" > $dest/usr/libexec/scripts/hal-system-power-suspend-hybrid
#!/bin/sh
/usr/sbin/standby

EOF


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages 

cd $dest
makepkg -l y -c n $dest.txz
cd $buildir

